@@ -7,12 +7,12 @@ from circlator import external_progs, __version__
 from circlator import __version__ as circlator_version
 
 
-def get_all_versions(filehandle, raise_error=True, debug=False):
+def get_all_versions(filehandle, raise_error=True, debug=False, assembler=None):
     if filehandle is not None:
         print('Circlator version:', circlator_version, file=filehandle)
         print('\nExternal dependencies:', file=filehandle)
 
-    external_progs.check_all_progs(verbose=False, raise_error=raise_error, filehandle=filehandle, debug=debug)
+    external_progs.check_all_progs(verbose=False, raise_error=raise_error, filehandle=filehandle, debug=debug, assembler=assembler)
 
     if filehandle is not None:
         print('\nPython version:', file=filehandle)
